*=====================================================================================*
*                                  preparation.do                                     *
*=====================================================================================*

*-------------------------------------------------------------------------------------*
*  van den Berg, Kalmijn, Leopold, 2018, replication files                            *
*  last update: 27 March 2018                                                         *
*  data: soeplong 1984-2015, version 32.1, release 2017                               *
*-------------------------------------------------------------------------------------*

*-----------------------------------------------------------------------------*
*  Prepare data sets                                                          *
*-----------------------------------------------------------------------------*
*-----------------------------------------------------------------------------*
* Prepare identifier parents 

** In kids file
use	 	"${data}\kidl.dta", clear 
set more off

replace k_phead=. 	if 	k_rel!=3 & k_rel!=21 & k_rel!=23	// only identify head of the household if (adoptive)child of household

foreach var of varlist k_phead k_pmum {
tostring `var', replace
sort pid syear   
bysort pid : egen `var'a = mode(`var')
}
*

bysort pid: keep if _n==1
keep pid k_pheada k_pmuma

save 	"${posted}\kid1.dta", replace

** In pbrutto and pgen
use syear pid hid stell using 	"${data}\pbrutto.dta", clear
merge 	1:1 pid syear using  	"${data}\pgen.dta", 				///
		keepusing (pid syear hid pgpartnr)							///
		nogen
merge 	1:1 pid syear using  	"${data}\jugendl.dta"

gen syeary	=	syear if _merge==3										
bysort hid syear: egen syearyouth	=	min(syeary)

foreach var of varlist pid pgpartnr {
tostring `var',	gen (`var'b)
gen head`var'a 		=	`var'b		if	stell==0 	& syear==syearyouth
bysort hid syear:	egen head`var' = mode(head`var'a)
}
*
replace headpid			= "" 	if 	stell!=20 & stell!=21 	// empty if the head is the youth is not child of the head
replace headpgpartnr	= "" 	if 	stell!=22 & stell!=12	// empty if the head is the youth is not child of the partner of the head

keep if _merge==3

keep pid syear headpid headpgpartnr
save "${posted}\kid2.dta", replace

*-----------------------------------------------------------------------------*
* Prepare income data
use "${data}\pequiv.dta"

** Equivalise post-government household income (square root scale)
replace i11102 = . if i11102 < 0
gen einc = i11102 / (d11106^0.5)

** Weight by consumer price index
clonevar price 	= y11101
replace price	= . if price < 0
gen pw 			= 100/price
gen eincp		= einc * pw
replace eincp 	= . if eincp < 2000 // set implausible values to missing

* Calculate percent of year-specific median income
gen pmi = .
	forvalues x = 1984/2015 {
		 sum eincp if syear == `x', d
		 replace pmi = eincp/r(p50) if syear == `x'		//  % of median income
		 }
	*
	recode pmi	(0/.59999    	= 1 "< 60%"      	) ///
				(.60/.999999  	= 2 "60% - 100%"  	) ///
				(1.00/1.499999	= 3 "100% - 150%"  	) ///
				(1.50/1000000   = 4 "> 150%"    	) ///
				(else        	= 5 "Missing"    	) ///
		 , gen(pmic)
label variable pmic "Percent of year-specific median income (categorical)"

keep pid hid syear pmic h11101 h11102 d11105 d11102ll h11103 i11110 d11109
save "${posted}\pequivinc.dta",replace 

*-----------------------------------------------------------------------------*
* Prepare parents data
use pid syear hid pgfamstd pgpartz pgmonth pgpartnr using "${data}\pgen.dta", clear

merge 1:1 pid syear using "${data}\biol.dta", keep(master matched) nogen ///
		keepusing(ll0312 ll0313 ll0314 ll0315 ll0316 ll0317 ll0318 ll0319 ll0320) 
merge 1:1 pid syear using "${data}\pequiv.dta", keep(master matched) nogen ///
		keepusing(pid syear d11106 d11109 d11102ll) 
merge 1:1 pid syear using "${data}\pl.dta", keep(master matched) nogen ///
		keepusing(pld0166 plh0182) 
merge m:1 pid using "${data}\ppfad.dta", keep (master matched) nogen ///
		keepusing (loc1989)
sort pid syear

** 	Parental family structure information

replace pgfamstd = 1 if pgpartz>=1 	| 	pgfamstd==6 | 	pgfamstd==7	
recode pgfamstd (1 = 1) (2 3 4 8 = 2) (5 = 3) (else = .)

foreach num of numlist 1/5 {
	sort pid syear
	bys pid: replace pgfamstd 	= pgfamstd[_n-`num'] 	if pgfamstd==.
	bys pid: replace pgfamstd 	= pgfamstd[_n+`num'] 	if pgfamstd==. 
	}
	*
foreach var of varlist ll* {
bys pid: egen `var'a = max(`var')
}
*

rename 	(ll0312a ll0314a ll0315a ll0317a ll0318a ll0320a ll0313a ll0316a ll0319a) 				///
		(yearmar1 yearmar2 yearmar3 yearmar4 yearmar5 yearmar6 pgfamstd2 pgfamstd4 pgfamstd6)

foreach var of varlist yearmar* {
	replace `var' = . if `var'<1
	replace `var' = `var' + 1900 if `var'!=. & `var'<100	
	}
	*
foreach num of numlist 1 3 5 { 
	gen mar`num'		=	1 	if 	yearmar`num'!=.	
	}
	*
foreach num of numlist 2 4 6 { 
	gen mar`num'		=	2 	if 	yearmar`num'!=. & pgfamstd`num'==2  		
	replace mar`num'	=	3 	if 	yearmar`num'!=. & pgfamstd`num'==3		
	}		
	*	
	
bys pid: gen syearchange	=	syear if pgfamstd!=pgfamstd[_n-1] & pgfamstd!=. & pgfamstd[_n-1]!=.
gen monthchange	=	pgmonth if syearchange==syear
bysort pid: egen yearmar7 = min(syear) 
gen monthmar7	=	pgmonth if syear==yearmar7

foreach num of numlist 8/14 {
	bysort pid: egen yearmar`num'= min(syearchange)
	bysort pid: egen monthmar`num'= min(monthchange)
	replace  syearchange =. if syear<=yearmar`num'	
	replace  monthchange =. if syear<=yearmar`num'	
	}
	*
	
foreach num of numlist 7/14 {
	gen pgfamstd`num'= pgfamstd 	if 	syear==yearmar`num'
	bysort pid: egen mar`num'= min(pgfamstd`num')
	gen partn`num'= pgpartnr if syear==yearmar`num'
	bysort pid: egen partnr`num'= min(partn`num')	
	}
	*
		
** 	Variable for change in number of householdmembers and well being
recode plh0182 (-5 -2 -1 = .)
sort pid syear
foreach num of numlist 1 2 3 {
	bys pid: replace plh0182 = plh0182[_n-`num'] if plh0182==.
	}
	*

foreach num of numlist 2000 / 2015 {
	gen child`num'a 	= 1 if	syear == `num' & d11106<d11106[_n-1] & d11106[_n-1]!=.
	replace child`num'a 	= 0 if	syear == `num' & d11106==d11106[_n-1] & d11106[_n-1]!=.
	gen ls`num'a 		= 	plh0182 	if 	syear==`num'
	bys pid: egen child`num' 	= 		max(child`num'a)
	bys pid: egen ls`num' 		= 		max(ls`num'a)
	drop ls`num'a child`num'a
}
*
	
**	Make 1 line per respondent and save
bys pid: gen n = _n
keep if n==1

keep 	pid yearmar* hid* monthmar* partnr* mar* d11102ll d11102ll loc1989 ls* n* child*

tostring pid partnr*, replace
rename * x*

** Save as parentsdata
save "${posted}\parents.dta", replace

keep if xd11102ll ==1 
save "${posted}\father.dta", replace

use "${posted}\parents.dta", replace

keep if xd11102ll ==2 
save "${posted}\mother.dta", replace


*-----------------------------------------------------------------------------*
*  Merge data set	                                                          *
*-----------------------------------------------------------------------------*
use "${data}\jugendl.dta"

merge 1:1 pid using "${posted}\kid1.dta"		, 	keep (1 3) nogen 	
merge 1:1 pid syear using "${posted}\kid2.dta"	,	keep (1 3) nogen

** Merge with parents data 
gen xpid 		= k_pheada 
replace xpid 	= headpid		if 	xpid=="." 	| xpid=="" 	| xpid=="-2"
replace xpid 	= headpgpartnr	if 	xpid=="." 	| xpid=="" 	| xpid=="-2"
merge m:1 xpid using "${posted}\father.dta"		,	keep (1 3)
rename _merge merged
rename x* fath* 

gen xpid 		= k_pmuma 
replace xpid 	= headpid		if 	xpid=="." 	| xpid=="" 	| xpid=="-2" 
replace xpid 	= headpgpartnr 	if 	xpid=="." 	| xpid=="" 	| xpid=="-2" 
merge m:1 xpid using "${posted}\mother.dta"		,	keep (1 3)
gen nopara 		= 1 if _merge==1 & merged==1
drop _merge
rename x* mum* 

** From other files
clonevar jugend=pid 
merge 1:1 pid syear using "${data}\pl.dta",		///
	keepusing (pid hid syear plb0022 pld0132 pld0133 plh0182 plh0151  plg0012-plg0070 plb0176 plb0186) 
bysort pid : egen jugendpid = max(jugend) 
// some are in pl and jugendl in the same year, other only in jugendl in the first year. Keep both
keep if jugendpid==pid | _merge==1		
drop _merge

merge 1:1 pid syear using "${data}\ppfadl.dta"		,	keep (1 3) nogen 		///
	keepusing (gebmonat)
merge 1:1 pid syear using "${data}\pgen.dta"		, 	keep (1 3) nogen 		///
	keepusing (pgmonth pgcasmin pgfamstd)
merge 1:1 pid syear using "${posted}\pequivinc.dta"	, 	keep (1 3) nogen 
merge m:1 hid syear using "${data}\hgen.dta"		, 	keep (1 3) nogen 		///
	keepusing (hgowner hgcondit)
merge 1:1 pid syear using "${data}\pbrutto.dta"		, 	keep (1 3) nogen 		///
	keepusing(pid syear stell) 

*-----------------------------------------------------------------------------*
*  Prepare variables	                                                  *
*-----------------------------------------------------------------------------*
label language EN

* Make variables of jugendl and kidl on cluster level
foreach var of varlist jl* mum* fath* {
	bysort pid: egen x`var' = mode(`var')
	drop `var'
	rename x`var' `var'		
	}
	*
* Age and survey year
replace gebmonat = jl0234 if gebmonat	==	-1
recode 	pgmonth gebmonat (-8 -3 -2 -1 . =	6) 	
gen yearmonth 	= ym(syear, pgmonth)
gen birthym 	= ym(jl0233, gebmonat)
format birthym yearmonth %tm
gen age			= (yearmonth - birthym)/12

sort pid syear
bys pid: egen max_age	=	max(age)
bys pid: egen min_age	=	min(age)
bys pid: egen min_syear = 	min(syear) 
bys pid: egen max_syear = 	max(syear)
	
* Father=1 if there is only info about father or living with father 
gen father = 1 if 	mummar7==. & syear==min_syear & jl0288!=2 & jl0288!=3		| ///
					jl0288==2
bys pid: egen fath = max(father) 

* Make variables that uses info father if there is only info from father
foreach x of newlist yearmar1-yearmar14 partnr7-partnr14 monthmar7-monthmar14	///
	mar1-mar14 loc1989 child2001-child2015 {
		gen `x' 		= 	mum`x' 		if 	fath==.
		replace `x' 	= 	fath`x' 	if 	fath==1
	}
	*

*-----------------------------------------------------------------------------*
*  Outcome variable		                                                	  *
*-----------------------------------------------------------------------------*

* Leaving home
gen hidfirst = hid if age==min_age
bysort pid: egen hidf = max(hidfirst)
gen moved		=	0 	if	hid==hidf | 								///
							hid!=hidf &	stell>=20 & stell<25
replace moved	=	1 	if 	hid!=hidf & stell<20 |						///
							hid!=hidf & stell>25

* Age moved
gen agemoveda		 	=	age if 	moved==1
bys pid: egen agemoved	=	min(agemoveda)

** Household information after last survey
gen obsaf=. 
foreach num of numlist 2001/2015 {
replace obsaf = 1 if 	max_syear + 1 == `num' & child`num'!=.
}
*

*-----------------------------------------------------------------------------*
* 	Main independent variable: family Structure                                 *
*-----------------------------------------------------------------------------*

** Age per marital status
foreach num of numlist 1/6 {
		gen age`num' = yearmar`num'- jl0233
	}
	*
foreach num of numlist 7/14 {
		recode monthmar`num' (-2=6)
		gen ymonth`num' = ym(yearmar`num', monthmar`num')
		format ymonth`num' %tm
		gen age`num' =  (ymonth`num' - birthym)/12
	}
	*
foreach x of newlist ymar ymarb mary0 py1 py2 fam marry divorce div wid mar {
		gen `x' = . 
}
*

** Pointer to important syears: ymar: marstat before birth child, ymarb: marstat when child started jugendl
foreach num of numlist 1/14 { 
		replace ymar 	= `num' 	if age`num'<=0 
		replace ymarb 	= `num' 	if age`num'<=min_age
		replace mary0	= 1 		if ymar==`num' & mar`num'!=1
	}
	*
foreach num of numlist 1/14 { 
		replace ymar	= `num' 	if age`num'>0 & age`num'<4 & mary0==1 & mar`num'==1
	}
	*
replace ymar = 7 if ymar==. 	// people who only are observed after child was born

** Partnernumber in year child was younger than 1 and when child is 17
tostring py*, replace
foreach num of numlist 7/14 {
		replace py1 	= 	partnr`num' 	if ymar==`num'
		replace py2		= 	partnr`num' 	if ymarb==`num'
	}
	*
replace py1  = "." if  py1== "-2"
replace py2  = "." if  py2== "-2"

** Variable whether parent was ever single/divorced, widowed or married before jugendl
foreach num of numlist 1/14 {
		replace div 	= 	1 if 	`num'==ymar & mar`num'!=1 | 				///
									`num'>ymar & `num'<=ymarb & mar`num'==2 	
		replace wid 	= 	1 if 	`num'>ymar & `num'<=ymarb & mar`num'==3 
		replace mar 	= 	1 if 	ymarb==`num' & mar`num'==1
		}
	*

** Make familystructure variable 
replace fam		=	1	if 	mar==1 	 & div==. 	& wid==. 						| 	/// 1. Intact family
							py1==py2 & py1!="." & div==1   & wid==.					// 		back together with partner
replace fam		=	2 	if 	mar==1 	 & div==1 	& fam==.   & wid==. 			| 	/// 2. Divorced with stepparent
							mar==1   & div==. 	& py1!=py2 & py1!="." & py2!="."	// 		continuously married, different partners 
replace fam 	= 	3	if 	div==1   & wid==.	& mar==. 							//  3. Divorced without stepparent
replace fam 	= 	4 	if 	wid==1 	 & py2!="."										//  4. Widowed with step 
replace fam 	= 	5 	if 	wid==1 	 & py2=="." 									//  5. Widowed without step

replace fam		=	2 	if jl0279!=15 & jl0279!=-2 & mar1==. & age7>4 & mar==1 & wid==. 	// use records child if no mar hist. and started age>4

** Make variable marry and divorce if custodial parent marries or divorces after age 17
foreach num of numlist 1/14 {
		replace marry 	= `num' if 	mar`num'==1 & age`num'>min_age & age`num'<age		 
		replace fam 	= 2 if 	fam ==3 & marry==`num' & syear>=yearmar`num' | 			///
								fam ==1 & marry==`num' & syear>=yearmar`num'
		replace divorce	= `num' if 	mar`num'==2 & age`num'>min_age & age`num'<age   	
		replace fam 	= 3 if 	fam ==1 & divorce==`num' & syear>=yearmar`num' | 		///
								fam ==2 & divorce==`num' & syear>=yearmar`num'
		replace fam 	= 5 if 	fam ==4 & divorce==`num' & syear>=yearmar`num'	
		}
		*
bys pid: egen fammax = max(fam)

*-----------------------------------------------------------------------------*
* 	Other variables									                          *
*-----------------------------------------------------------------------------*
* Homeowner
recode hgowner (1=1 "Owner") (2 3 = 0 "Tenant") (else = .), gen(owner)

* Housing conditions
recode hgcondit (1  = 0 "Good condition") (2 3 4 = 1 "Bad condition")(-1 . =.), gen(hcondit)

// replace housing variables of same household
recode pmic (5	=	.)
foreach var of varlist owner hcondit pmic {
	sort hid syear
	bysort hid: replace `var' = `var'[_n-1] if `var'==.
	bysort hid: replace `var' = `var'[_n+1] if `var'==.
	bysort hid: egen `var'mode = mode(`var')
	replace `var'=`var'mode if `var'==.
	}
	*

* Relationship
gen partner=.
replace partner = 1 if 	pld0132==1 | pgfamstd==1 	| pgfamstd==7 | pld0133==1 	| 	///
						age==min_age & jl0038>=1 & jl0038<6 
replace partner = 0 if 	partner==. & pld0132==2 	| partner==. & jl0038==6 	|  	///
						partner==. & pgfamstd==3
sort pid syear
bys pid: replace partner = partner[_n-1] if partner==. 

* Education and employment
gen eduemp			=	.
replace eduemp	 	=	1	if	plg0013>=1 	& plg0013<=6	 					|	/// 	general education
								plg0016==4 
replace eduemp		=	2	if	plg0016!=4 	& plg0016!=.  & plg0016>=1			| 	///		vocational education
								plg0021>=1 	& plg0021<=8 						|	///
								plb0022==3										| 	///
								plg0023>=1 	& plg0023<=8 						|	///
								plg0039==1										|	///
								plg0066==1											
replace eduemp	 	=	3	if	plg0014>=1 	& plg0014<=6							// 		higher education
recode plb0022 (1 2 4 5 8 = 1)
replace eduemp		=	0	if 	plb0022==1 & plg0012!=1								//		employed
replace eduemp	 	=	4 	if 	plb0022>5 	& plb0022<8	 							//		social year or military	
replace eduemp		=	5	if 	plb0022==9 	& plg0012==2						|  	///		not employed, not in education
								eduemp==. 	& age!=min_age
							
gen eduemployyouth		=	0	if  jl0013==1	& 	jl0125==6
replace eduemployyouth	=	1	if	jl0125>=1 	&	jl0125<5 | jl0125>=7
replace eduemployyouth	=	2	if	jl0125==5
replace eduemployyouth	=	4	if 	jl1402==1
replace eduemployyouth	=	5	if	jl0013==2	&	jl0125==6

replace eduemp = eduemployyouth if age==min_age & eduemp==. 
		
* Life satisfaction parents
gen lsmum=.
foreach num of numlist 2000/2015 { 
	replace lsmum = mumls`num' 	if syear==`num'
	replace lsmum = fathls`num' if syear==`num' & mumls`num'==.
	} 
	*
sort pid syear
bys pid: replace lsmum = lsmum[_n-1] if lsmum==.
bys pid: replace lsmum = lsmum[_n+1] if lsmum==. & age<agemoved

* Quality parent-child relationship
foreach num of numlist 27 26 35 36 {
	recode jl00`num' (-8 -1 5 = .) (1=4) (2=3) (3=2) (4=1) if `num'<30
	recode jl00`num' (-8 -1 6 = .) if `num'>30
	egen std`num'= std(jl00`num') 
	}	
	*
foreach num of numlist 40 43 44 46 48 50 52 54 56 {
	recode jl00`num' (1=5) (2=4) (3=3) (4=2) (5=1) (-2 -1 -8 =.)
	egen std`num'= std(jl00`num') 
	}	
	*

alpha std27 std36 std40 std43 std44 std46 std48 std50 std52 std54 std56, gen(conm) 
egen contact = std(conm)

* Schoolinvolvement
gen schoolinv = 0 if jl0168<=2 | jl0169<4							
recode schoolinv (.=1) 												

* Residential mobility 
recode jl0273 (-1 . =2 "Missings") (1 2 = 0 "Area grew up in") (3=1 "Other area"), gen(area)


* Gender
recode d11102ll (1=1 "Male") (2=0 "Female"), gen(male)

* Birth year
rename jl0233 byear

* Household members under age 18
gen hhdmem = h11101 + h11102
replace hhdmem = hhdmem - 1 if age<18

* East or West Germany
recode loc1989 (1=1 "East") (2=2 "West") (3=3 "Abroad") (-2 -1 . = 4 "Missing"),gen(loc)

*-----------------------------------------------------------------------------*
* 	Add wave for drop-outs					                                              *
*-----------------------------------------------------------------------------*
save "${posted}\data.dta", replace

keep if age		==	max_age & obsaf==1  & agemoved==. 
replace age 	= 	age+1
replace syear	= 	max_syear+1

foreach num of numlist 2001/2015 {
	replace moved=1 if `num'==syear & child`num'==1 
	replace moved=0 if `num'==syear & child`num'==0 
}
*
gen movafa = 1 if moved==1

save "${posted}\datab.dta", replace

use "${posted}\data.dta", clear

merge 1:1 pid syear using "${posted}\datab.dta", nogen

* New age at moving variable
bys pid: egen movaf = max(movafa)
gen agem 			= agemoved
replace agem 		= max_age+1 if movaf==1

* New age variable
gen ageyrs 			= int(age)

*-----------------------------------------------------------------------------*
* 	Lag variables			                                                  *
*-----------------------------------------------------------------------------*
foreach var of varlist hhdmem partner lsmum pmic owner hcondit  hgcondit fam eduemp  {
	sort pid syear
	bys pid: gen `var'l = `var'[_n-1] 
	replace `var'l		= `var' if syear==min_syear
	}
	*

*-----------------------------------------------------------------------------*
* 	Select sample			                                                  *
*-----------------------------------------------------------------------------*
sort pid syear
bys pid: gen n = _n
drop if min_syear==2000															| ///
		n==1																	| ///
		jl0288==2 																| ///
		fath==1 & jl0288>2														| ///
		jl0288==4																| ///
		min_age == agemoved														| ///
		nopar==1																| ///
		fammax>3																| ///
		age>agem																| ///
		n==2 & ageyrs>= 21														| ///
		min_age>19																| ///
		min_age<16

gen missing = 1 if 		area==2 | area==-2 | pmicl==. | pmicl==5 | partnerl==. 	| ///		
						contact==. | lsmuml==. | loc==4 | ownerl==. 			| ///
						hconditl==. | hgconditl==-1 | eduempl==.
bys pid: egen max_miss = max(missing)
drop if max_miss==1

*-------------------------------------------------------------------------------------*
*-------------------------------------------------------------------------------------*

save "$posted/data.dta", replace

*-------------------------------------------------------------------------------------*
*-------------------------------------------------------------------------------------*
