*=====================================================================================*
*                                  analysis.do                                        *
*=====================================================================================*

*-------------------------------------------------------------------------------------*
*  van den Berg, Kalmijn, Leopold, 2018, replication files                            *
*  last update: 27 March 2018                                                         *
*  data: soeplong 1984-2015, version 32.1, release 2017                               *
*-------------------------------------------------------------------------------------*
* Load prepared data
use "$posted/data.dta", clear
set more off

*-----------------------------------------------------------------------------*
*  Description                                                                *
*-----------------------------------------------------------------------------*

* Table 1
center min_syear contact lsmuml

// women
preserve
	keep if male==0
	keep if n==2
	
	foreach var of varlist pmicl eduempl loc	 {
	fre `var' if faml==1
	fre `var' if faml==2
	fre `var' if faml==3
	}
	*
	tabstat moved 															///
	c_contact schoolinv	lsmuml												///
	area 																	///
	ownerl hconditl  														///
	hhdmeml partnerl min_syear								 				///
	, statistics(mean max min sd)  f(%9.3g)  by(faml)
restore

// men
preserve
	keep if male==1
	keep if n==2
	
	foreach var of varlist pmicl eduempl loc	 {
	fre `var' if faml==1
	fre `var' if faml==2
	fre `var' if faml==3
	}
	*
	tabstat moved 															///
	c_contact schoolinv	lsmuml												///
	area 																	///
	ownerl hconditl  														///
	hhdmeml partnerl min_syear								 				///
	, statistics(mean max min sd)  f(%9.3g)  by(faml)
restore

*-----------------------------------------------------------------------------*
*  Analysis                                                                *
*-----------------------------------------------------------------------------*

* Table 2: leaving home early before age 20, women

preserve	

	keep if male==0 & ageyrs<=19

	// Model 1
	logit moved i.faml ib19.ageyrs	 										///			 			
		i.loc hhdmeml c_min_syear 											///							
		, robust cluster(pid) or 																
	estimates store m1w, title(Model 1) 
	
	// Model 2
	logit moved i.faml ib19.ageyrs			 								///
		i.loc hhdmeml c_min_syear											/// 
		ib3.pmicl i.ownerl i.hconditl 										/// 
		c_contact i.schoolinv c.c_lsmuml  									///	
		i.area 																///	
		, robust cluster(pid) or
	estimates store m2w, title(Model 2) 

	// Model 3
	logit moved i.faml ib19.ageyrs			 								/// 
		i.loc hhdmeml c_min_syear											/// 
		i.eduempl	 														///	
		i.partnerl 															///	
		, robust cluster(pid) or
	estimates store m3w, title(Model 3) 

	// Model 4
	logit moved i.faml ib19.ageyrs			 								/// 
		i.loc hhdmeml c_min_syear											/// 
		ib3.pmicl i.ownerl i.hconditl 										/// 
		c_contact i.schoolinv c.c_lsmuml  									///	
		i.area 																///	
		i.partnerl 															///	
		i.eduempl	 														///	
		, robust cluster(pid) or
	estimates store m4w, title(Model 4) 
	
	** Table
	esttab m1w m2w m3w m4w using "${tables}/table_2.rtf",   replace			///
		b(2) starlevels(+ 0.10 * 0.05 ** 0.01 *** 0.001)					///
		eform se wide 
		
restore
	

* Table 3: leaving home early before age 22, men
preserve	

	keep if male==1 & ageyrs<=21

	// Model 1
	logit moved i.faml ib19.ageyrs	 										///			 			
		i.loc hhdmeml c_min_syear 											///							
		, robust cluster(pid) or 																
	estimates store m1m, title(Model 1) 
	
	// Model 2
	logit moved i.faml ib19.ageyrs			 								///
		i.loc hhdmeml c_min_syear											/// 
		ib3.pmicl i.ownerl i.hconditl 										/// 
		c_contact i.schoolinv c.c_lsmuml  									///	
		i.area 																///	
		, robust cluster(pid) or
	estimates store m2m, title(Model 2) 

	// Model 3
	logit moved i.faml ib19.ageyrs			 								/// 
		i.loc hhdmeml c_min_syear											/// 
		i.eduempl	 														///	
		i.partnerl 															///	
		, robust cluster(pid) or
	estimates store m3m, title(Model 3) 

	// Model 4
	logit moved i.faml ib19.ageyrs			 								/// 
		i.loc hhdmeml c_min_syear											/// 
		ib3.pmicl i.ownerl i.hconditl 										/// 
		c_contact i.schoolinv c.c_lsmuml  									///	
		i.area 																///	
		i.partnerl 															///	
		i.eduempl	 														///	
		, robust cluster(pid) or
	estimates store m4m, title(Model 4) 
	
	** Table
	esttab m1m m2m m3m m4m using "${tables}/table_3.rtf",   replace			///
		b(2) starlevels(+ 0.10 * 0.05 ** 0.01 *** 0.001)					///
		eform se wide 

restore

* Table 4: khb analysis, women

preserve

	keep if male==0 & ageyrs<=19

	// Only with controls	
	foreach var of varlist pmicl ownerl hconditl schoolinv area partnerl eduempl {
		khb logit moved i.faml  ||										/// 
			i.`var'						 								/// 
			, concomitant(ib19.ageyrs i.loc c.hhdmeml c.c_min_syear)	///
			robust cluster(pid) summary
	}
	*
	
	foreach var of varlist c_contact c_lsmuml {
		khb logit moved i.faml  ||										/// 
			c.`var'														///
			, concomitant(ib19.ageyrs i.loc c.hhdmeml c.c_min_syear)	///
			robust cluster(pid) summary
	}
	*
	
	// Full model
		khb logit moved i.faml  ||										/// 
			i.pmicl i.ownerl i.hconditl 								/// 
			c.c_contact i.schoolinv c.c_lsmuml 							///	
			i.area 														///	
			i.partnerl 													///	
			i.eduempl	 												///		
			, concomitant(ib19.ageyrs i.loc c.hhdmeml c.c_min_syear)	///
			robust cluster(pid) summary disentangle notable

restore

* Table 5: khb analysis, men
preserve

	keep if male==1 & ageyrs<=21
	
	// Only with controls
	foreach var of varlist pmicl ownerl hconditl schoolinv area partnerl eduempl {
		khb logit moved i.faml  ||										/// 
			i.`var'						 								/// 
			, concomitant(ib19.ageyrs i.loc c.hhdmeml c.c_min_syear)	///
			robust cluster(pid) summary
	}
	*
	
	foreach var of varlist c_contact c_lsmuml {
		khb logit moved i.faml  ||										/// 
			c.`var'														///
			, concomitant(ib19.ageyrs i.loc c.hhdmeml c.c_min_syear)	///
			robust cluster(pid) summary
	}
	*
	
	// Full model
		khb logit moved i.faml  ||										/// 
			i.pmicl i.ownerl i.hconditl 								/// 
			c.c_contact i.schoolinv c.c_lsmuml 							///	
			i.area 														///	
			i.partnerl 													///	
			i.eduempl	 												///		
			, concomitant(ib19.ageyrs i.loc c.hhdmeml c.c_min_syear)	///
			robust cluster(pid) summary disentangle notable

restore

************************************************************************************
** -- Figure 1 -- **
************************************************************************************

drop if ageyrs<17 | ageyrs>25
	
stset ageyrs, id(pid) failure(moved)

// women
preserve
	keep if male==0
	foreach num of numlist 1 2 3 {
		sts gen km`num'=s if faml==`num'
		sts gen ub`num'=ub(s) if faml==`num'
		sts gen lb`num'=lb(s) if faml==`num'
		}
		*
	
	twoway 	(rarea ub2 lb2 ageyrs, sort color(gs15))							///
			(rarea ub3 lb3 ageyrs, sort color(gs12))							///
			(rarea ub1 lb1 ageyrs, sort color (gs8))							///
	||  	(line km1 ageyrs, sort color(gs0))  								///
			(line km2 ageyrs, sort color(gs10))									///
			(line km3 ageyrs, sort color(gs5))									///
			,	title("Women", size(medium) col(black))							///
				legend(off)														///
				xlabel	(17(1)25) 												///								
				xtitle("Age", size(small))										///	
				ylabel(0(.2)1,angle(horizontal))								///	
				graphregion(color(white) fcolor(white) icolor(white)) 					
	graph save Graph "${graphs}/fig1a.gph", replace
restore

// men
preserve
	keep if male==1
	foreach num of numlist 1 2 3 {
		sts gen km`num'=s if faml==`num'
		sts gen ub`num'=ub(s) if faml==`num'
		sts gen lb`num'=lb(s) if faml==`num'
		}
		*
	
	twoway 	(rarea ub2 lb2 ageyrs, sort color(gs15))							///
			(rarea ub3 lb3 ageyrs, sort color(gs12))							///
			(rarea ub1 lb1 ageyrs, sort color (gs8))							///
	||  	(line km1 ageyrs, sort color(gs0))  								///
			(line km2 ageyrs, sort color(gs10))									///
			(line km3 ageyrs, sort color(gs5))									///
			,	title("Men", size(medium) col(black))							///
				legend(off)														///
				xlabel	(17(1)25) 												///								
				xtitle("Age", size(small))										///	
				ylabel(0(.2)1,angle(horizontal))								///	
				graphregion(color(white) fcolor(white) icolor(white)) 					
	graph save Graph "${graphs}/fig1b.gph", replace
restore

** Graph
graph combine "${graphs}/fig1a.gph" "${graphs}/fig1b.gph",						///
				title("Figure 1", size(medium) col(black))						///
				graphregion(color(white) fcolor(white) icolor(white)) 					
graph save Graph "${graphs}/figure1.gph"

